@@ -19,7 +19,7 @@ class TimestampSec(float):
     DEFAULT_DATETIME_FORMAT: ClassVar[str] = '%Y-%m-%dT%H:%M:%S'
     DEFAULT_DATE_FORMAT: ClassVar[str] = '%Y-%m-%d'
 
-    def __new__(cls, value: int | float | datetime.datetime) -> Self:
+    def __new__(cls, value: int | float | datetime.datetime) -> 'TimestampSec':
         if isinstance(value, datetime.datetime):
             if value.tzinfo is None:
                 raise ValueError("Attempt to make Timestamp from naive datetime"
@@ -41,11 +41,11 @@ class TimestampSec(float):
         return datetime.datetime.fromtimestamp(self, tz=timezone)
 
     @staticmethod
-    def now() -> Self:
+    def now() -> 'TimestampSec':
         return TimestampSec(time.time())
 
     @classmethod
-    def from_iso_str(cls, string_value: str, default_timezone: datetime.timezone | None = None) -> Self:
+    def from_iso_str(cls, string_value: str, default_timezone: datetime.timezone | None = None) -> 'TimestampSec':
         datetime_ = datetime.datetime.fromisoformat(string_value)
         if datetime_.tzinfo is None:
             if default_timezone is None:
